{% extends 'base/layout.html' %}
{% load buttons %}

{% block content %}


<div class="pull-right noprint">
<a href="/plugins/ciscodnacnetbox/status/" class="btn btn-primary">
<span class="mdi mdi-view-dashboard" aria-hidden="true"></span> Status
</a>
</div>

<h1>Cisco DNA Center</h1>
<h2>Full Sync</h2>

<div class="row">
<div class="col-md-12">

<div class="table-responsive">

<table class="table table-hover table-headings">
<thead>
<tr>
<th>Cisco DNA Center</th>
<th>Sites</th>
<th>Devices</th>
</tr>
</thead>
{% for tenant, dnac in data.items %}
<tbody>
    <tr class="even">
        <td>
            {{ tenant }}
        </td>
        <td>
            {{ dnac.sites }}
        </td>
        <td>
            {{ dnac.devices }}
        </td>
    </tr>
</tbody>
{% endfor %}
</table>

</div>
</div>
</div>

{% endblock %}