{% extends 'generic/object_list.html' %}
{% load plugins %}
{% load render_table from django_tables2 %}

{% block title %}
Cisco DNA Center Settings
{% endblock %}
{% block breadcrumbs %}
<li class="breadcrumb-item"><a href="{% url 'plugins:ciscodnacnetbox:settings' %}">Cisco DNA Center Settings</a></li>
{% endblock %}

{{% block extra_controls %}
{% endblock extra_controls %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-12">
      <div class="card">
        <h5 class="card-header">Hosts</h5>
        <div class="card-body table-responsive">
          {% render_table table %}
        </div>
      </div>
    </div>
  </div>
  {% endblock %}