{% extends 'base/layout.html' %}
{% load buttons %}
{% load helpers %}

{% block content %}
<div class="pull-right noprint">
    {% block buttons %}{% endblock %}
    {% if request.user.is_authenticated and table_config_form %}
        <button type="button" class="btn btn-default" data-toggle="modal" data-target="#tableconfig" title="Configure table"><i class="fa fa-cog"></i> Configure</button>
    {% endif %}
    {% if permissions.add and 'add' in action_buttons %}
        {% add_button content_type.model_class|validated_viewname:"add" %}
    {% endif %}
    {% if permissions.add and 'import' in action_buttons %}
        {% import_button content_type.model_class|validated_viewname:"import" %}
    {% endif %}
    {% if 'export' in action_buttons %}
        {% export_button content_type %}
    {% endif %}
</div>
<h1>{% block title %}{{ content_type.model_class|meta:"verbose_name_plural"|bettertitle }}{% endblock %}</h1>
<div class="row">
    <div class="col-md-{% if filter_form %}9{% else %}12{% endif %}">
        {% with bulk_edit_url=content_type.model_class|validated_viewname:"bulk_edit" bulk_delete_url=content_type.model_class|validated_viewname:"bulk_delete" %}
        {% if permissions.change or permissions.delete %}
            <form method="post" class="form form-horizontal">
                {% csrf_token %}
                <input type="hidden" name="return_url" value="{% if return_url %}{{ return_url }}{% else %}{{ request.path }}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}{% endif %}" />
                {% if table.paginator.num_pages > 1 %}
                    <div id="select_all_box" class="hidden panel panel-default noprint">
                        <div class="panel-body">
                            <div class="checkbox-inline">
                                <label for="select_all">
                                    <input type="checkbox" id="select_all" name="_all" />
                                    Select <strong>all {{ table.rows|length }} {{ table.data.verbose_name_plural }}</strong> matching query
                                </label>
                            </div>
                            <div class="pull-right">
                                {% if bulk_edit_url and permissions.change %}
                                    <button type="submit" name="_edit" formaction="{% url bulk_edit_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-warning btn-sm" disabled="disabled">
                                        <span class="glyphicon glyphicon-pencil" aria-hidden="true"></span> Edit All
                                    </button>
                                {% endif %}
                                {% if bulk_delete_url and permissions.delete %}
                                    <button type="submit" name="_delete" formaction="{% url bulk_delete_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-danger btn-sm" disabled="disabled">
                                        <span class="glyphicon glyphicon-trash" aria-hidden="true"></span> Delete All
                                    </button>
                                {% endif %}
                            </div>
                        </div>
                    </div>
                {% endif %}
                {% include table_template|default:'responsive_table.html' %}
                <div class="pull-left noprint">
                    {% block bulk_buttons %}{% endblock %}
                    {% if bulk_edit_url and permissions.change %}
                        <button type="submit" name="_edit" formaction="{% url bulk_edit_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-warning btn-sm">
                            <span class="glyphicon glyphicon-pencil" aria-hidden="true"></span> Edit Selected
                        </button>
                    {% endif %}
                    {% if bulk_delete_url and permissions.delete %}
                        <button type="submit" name="_delete" formaction="{% url bulk_delete_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-danger btn-sm">
                            <span class="glyphicon glyphicon-trash" aria-hidden="true"></span> Delete Selected
                        </button>
                    {% endif %}
                </div>
            </form>
        {% else %}
            {% include table_template|default:'responsive_table.html' %}
        {% endif %}
        {% endwith %}
        {% include 'inc/paginator.html' with paginator=table.paginator page=table.page %}
        <div class="clearfix"></div>
        {% if table_config_form %}
            {% include 'inc/table_config_form.html' %}
        {% endif %}
    </div>
    {% if filter_form %}
        <div class="col-md-3 noprint">
            {% include 'inc/search_panel.html' %}
            {% block sidebar %}{% endblock %}
        </div>
    {% endif %}
</div>
{% endblock %}