class App:
    _NAME_ = "ciscodnacnetbox"
    _VERSION_ = "3.2.1"
    _DESC_ = "Cisco DNA Center Integration with NetBox"
    _AUTHOR_ = "Robert Csapo"
    _EMAIL_ = "rcsapo@cisco.com"
    _URL_ = "https://github.com/robertcsapo/ciscodnacnetbox"
